==> 0.0.1.tar.gz: android/src/main/java/co/hyperverge/hyperkyc_flutter/FLHyperKycHelper.java <==
package co.hyperverge.hyperkyc_flutter;

import android.util.Log;

import com.fasterxml.jackson.databind.ObjectMapper;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.Map;

import co.hyperverge.hyperkyc.data.network.BaseResponse;
import co.hyperverge.hyperkyc.data.network.DocCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceMatchApiDetail;

public class FLHyperKycHelper {
    public static final String TAG = FLHyperKycHelper.class.getCanonicalName();

    private FLHyperKycHelper() {
    }

    public static String getStringFromProperty(String property) {
        if (property != null) {
            return property;
        } else {
            return FLHyperKycConstants.EMPTY_STRING;
        }
    }

    public static JSONObject convertMapToJson(Map<String, String> map) {
        JSONObject object = new JSONObject();
        ObjectMapper objectMapper = new ObjectMapper();
        try {
            String json = objectMapper.writeValueAsString(map);
            object = new JSONObject(json);
        } catch (Exception e) {
            Log.e(TAG, e.getMessage());
        }
        return object;
    }

    public static String getResponseHeadersJsonString(Map<String, String> responseHeadersMap) {
        if (responseHeadersMap != null) {
            JSONObject responseHeadersJson = FLHyperKycHelper.convertMapToJson(responseHeadersMap);
            return responseHeadersJson.toString();
        } else {
            return FLHyperKycConstants.EMPTY_JSON_STRING;
        }
    }

    public static String getResponseResultJsonString(BaseResponse<DocCaptureApiDetail> docDataResponseResult, BaseResponse<FaceCaptureApiDetail> faceDataResponseResult, BaseResponse<FaceMatchApiDetail> faceMatchDataResponseResult) {
        if (docDataResponseResult != null) {
            Map responseResultMap = convertObjectToMap(docDataResponseResult);
            JSONObject responseResultJson = convertMapToJson(responseResultMap);
            return responseResultJson.toString();
        } else if (faceDataResponseResult != null) {
            Map responseResultMap = convertObjectToMap(faceDataResponseResult);
            JSONObject responseResultJson = convertMapToJson(responseResultMap);
            processResultObject(responseResultJson);
            return responseResultJson.toString();
        } else if (faceMatchDataResponseResult != null) {
            Map responseResultMap = convertObjectToMap(faceMatchDataResponseResult);
            JSONObject responseResultJson = convertMapToJson(responseResultMap);
            processResultObject(responseResultJson);
            return responseResultJson.toString();
        } else {
            return FLHyperKycConstants.EMPTY_JSON_STRING;
        }
    }

    public static Map convertObjectToMap(Object object) {
        final ObjectMapper objectMapper = new ObjectMapper();
        return objectMapper.convertValue(object, Map.class);
    }

    public static JSONObject processResultObject(JSONObject responseResultJson) {
        try {
            JSONArray details = responseResultJson.getJSONObject(FLHyperKycConstants.RESULT).getJSONArray(FLHyperKycConstants.DETAILS);
            JSONObject detail = (JSONObject) details.get(0);
            responseResultJson.getJSONObject(FLHyperKycConstants.RESULT).remove(FLHyperKycConstants.DETAILS);
            responseResultJson.getJSONObject(FLHyperKycConstants.RESULT).put(FLHyperKycConstants.DETAILS, detail);
        } catch (Exception e) {
            Log.e(TAG, "processResultObject : " + e.getMessage());
        }
        return responseResultJson;
    }

}

==> 0.2.0.tar.gz: android/src/main/java/co/hyperverge/hyperkyc_flutter/FLHyperKycHelper.java <==
package co.hyperverge.hyperkyc_flutter;

import android.util.Log;

import com.fasterxml.jackson.databind.ObjectMapper;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.List;
import java.util.Map;

import co.hyperverge.hyperkyc.data.network.BaseResponse;
import co.hyperverge.hyperkyc.data.network.DocCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceMatchApiDetail;

public class FLHyperKycHelper {
    public static final String TAG = FLHyperKycHelper.class.getCanonicalName();

    private FLHyperKycHelper() {
    }

    public static String getStringFromProperty(String property) {
        if (property != null) {
            return property;
        } else {
            return FLHyperKycConstants.EMPTY_STRING;
        }
    }

    public static String getVariablesString(Map<String, Object> map) {
        JSONObject object = convertMapToJson(map);
        return object.toString();
    }

    public static JSONObject convertMapToJson(Map<String, Object> map) {
        JSONObject object = new JSONObject();
        ObjectMapper objectMapper = new ObjectMapper();
        try {
            String json = objectMapper.writeValueAsString(map);
            object = new JSONObject(json);
        } catch (Exception e) {
            Log.e(TAG, "convertMapToJson : " + e.getMessage());
        }
        return object;
    }

    public static String getResponseHeadersJsonString(Map<String, Object> responseHeadersMap) {
        if (responseHeadersMap != null) {
            JSONObject responseHeadersJson = FLHyperKycHelper.convertMapToJson(responseHeadersMap);
            return responseHeadersJson.toString();
        } else {
            return FLHyperKycConstants.EMPTY_JSON_STRING;
        }
    }

    public static String getResponseResultJsonString(BaseResponse<DocCaptureApiDetail> docDataResponseResult, BaseResponse<FaceCaptureApiDetail> faceDataResponseResult, BaseResponse<FaceMatchApiDetail> faceMatchDataResponseResult) {
        if (docDataResponseResult != null) {
            Map responseResultMap = convertObjectToMap(docDataResponseResult);
            JSONObject responseResultJson = convertMapToJson(responseResultMap);
            return responseResultJson.toString();
        } else if (faceDataResponseResult != null) {
            Map responseResultMap = convertObjectToMap(faceDataResponseResult);
            JSONObject responseResultJson = convertMapToJson(responseResultMap);
            processResultObject(responseResultJson);
            return responseResultJson.toString();
        } else if (faceMatchDataResponseResult != null) {
            Map responseResultMap = convertObjectToMap(faceMatchDataResponseResult);
            JSONObject responseResultJson = convertMapToJson(responseResultMap);
            processResultObject(responseResultJson);
            return responseResultJson.toString();
        } else {
            return FLHyperKycConstants.EMPTY_JSON_STRING;
        }
    }

    public static Map convertObjectToMap(Object object) {
        final ObjectMapper objectMapper = new ObjectMapper();
        return objectMapper.convertValue(object, Map.class);
    }

    public static JSONObject processResultObject(JSONObject responseResultJson) {
        try {
            JSONArray details = responseResultJson.getJSONObject(FLHyperKycConstants.RESULT).getJSONArray(FLHyperKycConstants.DETAILS);
            JSONObject detail = (JSONObject) details.get(0);
            responseResultJson.getJSONObject(FLHyperKycConstants.RESULT).remove(FLHyperKycConstants.DETAILS);
            responseResultJson.getJSONObject(FLHyperKycConstants.RESULT).put(FLHyperKycConstants.DETAILS, detail);
        } catch (Exception e) {
            Log.e(TAG, "processResultObject : " + e.getMessage());
        }
        return responseResultJson;
    }

}
